#delimit ;
*************************************************************;
*                                                           *;
*    Name    : CLCEXPTL.DO                V : 01            *;
*    Date    : 29 NOV 2004                                  *;
*    Infile  : HHXHOUS, FOODEXP, REGNFEXP, OCCNFEXP,        *;
*              HHXREM, HHYREG                               *;
*    Outfile : EXPEND04                                     *;
*                                                           *;
*    OBJECTIVE: Calculate total monthly expenditure         *;
*                                                           *;
*************************************************************;;

global IN ="C:\DATA\KIDS3\Version1.1";
global OUT="C:\DATA\KIDS3\Version1.1\constructed";

**----------------------------------------------------------------------**;
** HOUSING EXPENDITURE from HHXHOUS.DTA created by HHYHOUS.DO           **
** Variable mxrent includes rental expenses, imputed rent, & housing    **
** subsidy                                                              **;;
  
use $OUT\hhxhous, clear ;  
keep hhid2004 mxrent flagrent ;
sort hhid2004 ;
save $OUT\expend04, replace ;       


**----------------------------------------------------------------------**;

** FOOD EXPENDITURE from FOODEXP.DTA created by FOODEXP.DO              **

** NOTE: Food subsidies reported in employment section (10.2) are       **
**       sometimes larger than those reported consumed from payment (N2)**
**       in Section 3.  This is consistent with not consuming all the   **
**       the in-kind payment of food, that month, so these are not      **
**       included in total food expenditures                            **;;

use $OUT\foodexp ;
keep hhid2004 mxtfood flagfood ;
order mxtfood flagfood ;
sort hhid2004 ;
merge hhid2004 using $OUT\expend04 ;
tab _merge ; drop _merge;
sort hhid2004;
save $OUT\expend04,replace;          


**----------------------------------------------------------------------**;

** REGULAR NON FOOD EXPENDITURE from NF1X01.DTA created by CALCNF1X.DO  **;;

use $OUT\regnfexp ;

** Aggregate some of the regular non-food expenditures                  **;;

gen mxper = mxcig + mxalc + mxent + mxpca + mxnews + mxtel ;

gen mxtransp = mxtran1 + mxcar;

gen mxoth1 = mxwash+mxdues+mxdon+mxhelp ;

label var mxper    "04: Month exp: Personal Items" ;
label var mxtransp "04: Month exp: Transportation & Vehicle ";
label var mxoth1   "04: Month exp: Other Regular Non-Food";

** Verify all expenses are included                                     **;;

gen check = mxper + mxtransp + mxchil + mxoth1 + mxener + mxewr ;
*assert check == mxtot ;
                                
keep hhid2004 mxper mxtransp mxchil mxoth1 mxener mxewr flagreg ;

order mxper mxtransp mxchil mxoth1 mxener mxewr flagreg ;
sort hhid2004 ; 
merge hhid2004 using $OUT\expend04 ;
tab _merge ; drop _merge ;
sort hhid2004 ;

save $OUT\expend04, replace ;    


**----------------------------------------------------------------------**;

** OCCASIONAL NONFOOD EXP from NF2X02.DTA created by CALCNF2X.DO        **;;

use $OUT\occnfexp ;

** Aggregate some of the occasional non-food expenditures and put on a  **
** monthly basis                                                        **;;

gen mxhous   = ( yxkit   + yxhom   + yxbed    + yxfurn ) / 12 ;
gen mxcloth  = ( yxadult_cl  + yxkid_cl  + yxfab)        / 12 ;
gen mxhea    = ( yxdoc   + yxhosp  + yxmedica + yxtrad ) / 12 ;
gen mxoth2   = ( yxholi  + yxlux   + yxcerem  )          / 12 ;
gen mxed     = ( yxschool + yxuniv  + yxed_b   + yxedothr )          / 12 ;
gen mxinsure = ( yxins_l + yxmed_aid + yxins_s  )        / 12 ;

** Verify all expenses are included                                     **;;

gen check = mxhous + mxcloth + mxhea + mxoth2 + mxed + mxinsure ;
*assert round(check,1) == round( yxtot / 12 , 1) ;  ** PROBLEM HERE; 


lab var mxhous   "04: Avg Month exp: HH Items";
lab var mxcloth  "04: Avg Month exp: Clothing";
lab var mxhea    "04: Avg Month exp: Health Care";
lab var mxoth2   "04: Avg Month exp: Other Occassional Non-Food";
lab var mxed     "04: Avg Month exp: Educational";
lab var mxinsure "04: Avg Month exp: Insurance";

keep hhid2004 flagocc mx*;

order mx* flagocc ;
sort hhid2004;
merge hhid2004 using $OUT\expend04;
assert _merge == 3 ; drop _merge ;
sort hhid2004;
save $OUT\expend04, replace ;  


**----------------------------------------------------------------------**;

** REMITTANCE EXPENDITURE  from HHXREM.DTA created by CLCXREM.DO        **;;
   
use $OUT\hhxrem ;
keep hhid2004 mxtrem flagrem ;
sort hhid2004 ;
merge hhid2004 using $OUT\expend04 ;
tab _merge ; drop _merge ;
sort hhid2004 ;
save $OUT\expend04, replace ;           


**----------------------------------------------------------------------**;

** SUBSIDIES from HHYREG.DTA created using CLCYREG.DO                   **
** Transportation subsidies, not yet included in expenses               **;;

** Note: Food subsidies not included for double counting reasons        **
** Note: Housing subsidies already included in mxrent (CLCYHOUS.DO)     **;;

** Combine reported transportation expenses and subsidies               **;;

use $OUT\hhyreg ;                       
keep hhid2004 monthtvl monthhse montheat ;
sort hhid2004;
merge hhid2004 using $OUT\expend04 ;

recode monthtvl .=0;
recode montheat .=0;
recode monthhse .=0;

save $OUT\expend04, replace;

** In contrast to the food subsidies, transport subsidies were not
   explicitly asked about in Section 4.1.  Therefore, include here
   The subsidies are retained in the file for researchers who want
   to remove them                                                       **;;
 
                                                                                            
replace mxtransp = mxtransp + monthtvl ;

replace mxrent=0 if mxrent<0;

** Construct Total Monthly expenditure variable with and without        **
** Remittance expenditures                                              **;;
                                                  
gen totmexp04  = mxrent  + mxtfood + mxper + mxtransp + mxoth1 + mxener   +
               mxhous  + mxcloth + mxhea + mxoth2   + mxed   + mxinsure + 
               mxewr   + mxchil;


gen totmexpr04 = totmexp04 + mxtrem ; 

label var totmexp04  "04: Total Monthly Exp" ;
label var totmexpr "04: Total Monthly Exp w/ remit" ;
label var mxtransp "04: Month exp: Transport w/ subs";

label data "2004 Total Month Expenditure" ;

notes drop _dta ;

capture drop _merge;
 
compress;                                             
sort hhid2004;
save $OUT\expend04, replace ;

desc ;
summ ;
summ totmexp04 , det ;


