#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCXREM.DO               V : 02              *
*    Date    : 21 NOV 2004                                  *
*    Infile  : SECTION5.2                                   *
*    Outfile : HHXREM                                       *
*                                                           *
*    OBJECTIVE: Calculate the total value of remittances    *
*               sent by households (Section 5.2)            *
*                                                           *
*************************************************************;;

global IN  = "C:\DATA\KIDS3\version1.1";
global OUT = "C:\DATA\KIDS3\version1.1\CONSTRUCTED";

set more 0;

use $IN\section5_2.dta, replace;

recode s_cash_y -2=.;
recode s_cash_m -2=.;
recode s_inkin1 -2=.;
recode s_inkin2 -2=.;

** Construct 0/1 flag for missing annual total remittances              **;;

gen byte flagrem = (s_cash_y < 0 | s_inkin1 < 0 ) ;

** List the households with missing annual total expenditures           **
** and corresponding median values for imputations                      **;;

li if flagrem ;

**  Calculate total monthly remittances sent (sum for each household)   **
**  and the number of recipients (COUNT)                                **;;

gen int count = 1 ;

collapse (sum) flagrem s_cash_y s_inkin1 s_cash_m s_inkin2 count, by(hhid2004) ;

gen float mxremcas = s_cash_y / 12 if s_cash_y ~= . ;
gen float mxremkin = s_inkin1 / 12 if s_inkin1 ~= . ;
gen float mxtrem   = mxremcas + mxremkin ;

recast byte flagrem ;

label data "1998 Remittance Expenditure" ;

label var count    "04: Number of recipients" ;
label var mxremcas "04: Avg Month Remits exp:Cash" ;
label var mxremkin "04: Avg Month Remits exp:Kind" ;
label var mxtrem   "04: Avg Month Remits exp:All" ;
label var s_cash_y "04: Total Year Remits exp:Cash" ;
label var s_cash_m "04: Past Month Remits exp:Cash" ;
label var s_inkin1 "04: Total Year Remits exp:Kind" ;
label var s_inkin2 "04: Past Month Remits exp:Kind" ;
label var flagrem  "04: (1) if missing annual remit" ;

desc ;
summ ;

replace mxtrem=0 if mxtrem<0;

sort hhid2004 ;
save $OUT\hhxrem, replace ;

