#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYAGR.DO               V : 03              *
*    Date    : 27 FEB 2005                                  *
*    Infiles : SECTION 8.1.3 8.1.4 8.2.3 8.3 8.4 8.6        *
*                                                           *
*    Outfile : HHYAGR                                       *
*                                                           *
*    OBJECTIVE: Calculate agricultural production           *
*                                                           *
*    NOTES:     Distinguish between crops sold (at price    *
*               that the hh specifies) and crops not sold   *
*               (which we value at the average price across *
*               all hh on the assumption that all hh obtain *
*               the same utility from consuming the same    *
*               items)                                      *
*               We don't have Agr for N HH                  *
*                                                           *
*************************************************************;

capture log close;
global IN   = "C:\data\kids3\version1.1" ;
global OUT  = "C:\data\kids3\version1.1\constructed" ;

clear;
use $IN\cover, clear ;    
keep hhid2004;
sort hhid;
save $OUT\temp, replace;

use $IN\section8_1_3.dta; 
set more 1;         

** change pinjoi to brinjal;
replace cropname = "Brinjol" if cropname=="Pinjoi";

** QUERIES:
   1.WHY CROPS WHICH WERE FILLED IN AS "MAIZE" WERE THEN CODED AS MAIZE GRAIN?
     IN SOME CASES HH MEASURED OUTPUT IN PIECES, UNITS, BOXES OR BUNCHES - HOW CAN
     THIS BE GRAIN?
   2.WHAT IS NDLUBU?  CAN'T IT BE PUT INTO ANOTHER CATEGORY SINCE ONY 1 OBS?
   3.WHY WERE ALL RECORDS THAT JUST SAID "BEANS" ASSUMED TO BE GREEN BEANS AND NOT 
     DRY BEANS?
   4.SURELY PERI-PERI IS A PEPPER OR CHILI AND NOT A HERB?;

** COMBINE LIST OF CROPNAMES - ORIGINAL + OTHER;
encode crop_o, gen (crop_other);
encode cropname, gen(cropname1);

replace crop=26+crop_other if crop==24;

** DIFFERENTIATE BETWEEN GEM SQUASH, BUTTERNUT & PUMPKIN SINCE WEIGHTS DIFFER **;

replace crop=33 if cropname1==19;
replace crop=34 if cropname1==8;

** CHANGE MERTHI TO HERB SINCE ONLY 2 OBS.  **;
replace crop=25 if crop==29;

** COMBINE MILLET & SORGHUM **;
replace crop=3 if crop==12;

lab def crop 27"chillies" 28"dhal" 30"ndlubu" 31"pawpaw" 32"pineapple"
            33"gem squash" 34"butternut", add;
lab val crop crop;


****************************************************************
*                                                              *
*  AVERAGE PER ITEM MASS ASSUMED FOR DIFFERENT TYPES OF PRODUCE*
*                                                              *
***************************************************************;;

global maize=0.2;
global potato=0.2;
global orchardfruit=0.15;
global banana=0.15;
global pumpkin=1.5;
global greenveg=0.1;
global madumbe=0.08;  ** From Sheryl Hendricks;
global tomato=0.1;
global onion=0.1;
global otherveg=0.1;
global imifini=0.1;
global avocado=0.145;
global chili=.01;
global pawpaw=0.5;
global gemsquash=0.22;
global butternut=0.5;
global pineapple=0.6;
global sugarcane=0.5;
global bunch_banana=20; ** From Sheryl Hendricks;
global bunch_greenveg=1;
global bunch_imifino=0.2;
global bunch_herbs=0.3;


***************************************************************
*                                                             *
*  STEP 1: CALCULATE KGS OF CROPS PRODUCED                    *
*                                                             *
***************************************************************;;
                    
** Keep only those who report a harvest in the past year                   **;;
** Note: of the 2083 crops reported, 447 (21%) have supposedly not been harvested in past year**;

keep if crop_yn==1 & harvest==1;  ** grew crops and harvested crops;

** CALCULATE NET UNIT PRODUCTION AFTER LABOUR & LAND EXPENSES PAID IN KIND & LOSSES TO PESTS/THEFT/ROTTING**;

** IF COSTS / LOSSES ARE NOT KNOWN, ASSUME THEY ARE AVERAGE PROPORTIONATE COSTS/LOSSES.  CALC AVERAGES FROM
ONLY POSITIVE VALUES ON THE ASSUMPTION THAT IF REPORTED AS MISSING IT MUST HAVE BEEN NON-ZERO **;

** IF COSTS / LOSSES ARE GREATER THAN THE AMOUNT HARVESTED, ASSUME THEY ARE AVERAGE PROPORTIONATE COSTS/LOSSES.  CALC AVERAGES FROM
ONLY POSITIVE VALUES ON THE ASSUMPTION THAT IF REPORTED AS MISSING IT MUST HAVE BEEN NON-ZERO **;

gen prop_unitlab=unitlab/unithrv;
gen prop_unitland=unitland/unithrv;
gen prop_unitlost=unitlost/unithrv;

sum prop_unitlab if prop_unitlab>0 & unithrv>unitlab;
gen avg_prop_unitlab=_result(3);
sum prop_unitland if prop_unitland>0 & unithrv>unitland;
gen avg_prop_unitland=_result(3);
sum prop_unitlost if prop_unitlost>0 & unithrv>unitlost;
gen avg_prop_unitlost=_result(3);

gen flagAgC=0;
replace flagAg=1 if unitlab<0|unitlab==.;
replace flagAg=1 if unitland<0|unitland==.;
replace flagAg=1 if unitlost<0|unitlost==.;

replace unitlab=avg_prop_unitlab*unithrv if unitlab<0|unitlab==.|unitlab>unithrv;
replace unitland=avg_prop_unitland*unithrv if unitland<0|unitland==.|unitland>unithrv;
replace unitlost=avg_prop_unitlost*unithrv if unitlost<0|unitlost==.|unitlost>unithrv;

** IF NO INFORMATION ABOUT AMOUNT HARVESTED, SET TO ZERO & FLAG **;
replace flagAg=1 if unithrv<0|unithrv==.;
replace unithrv=0 if unithrv<0|unithrv==.;

** IF NO INFORMATION ABOUT AMOUNT SOLD, MUST SET TO ZERO.  THIS IS NOT REALLY A PROBLEM AS WE WILL STILL IMPUTE
   A VALUE FOR ALL THE HOME PRODUCTION VALUED AT THE AVG PRICE PER UNIT **;

replace unitsold=0 if unitsold<0|unitsold==.;

gen unit_prod=unithrv-unitlab-unitland-unitlost;

** ONLY 1 PROBLEM CASE REMAINING **;
list cropname unitname unithrv unitlab unitland unitlost if unit_prod<0;
**  THIS HH HARVESTED 10 UNITS AND USED 10 UNITS TO PAY FOR LAND.  CROP LOSSES (unitlost) WERE MISSING AND 
    THUS IMPUTED AS NON-ZERO.  THIS HH DID NOT SELL ANYTHING.  ALL IN ALL, SEEMS REASONABLE 
    TO ASSUME THAT NET PRODUCTION WAS ZERO **;

replace flagA=1 if unit_pro<0;
replace unit_prod=0 if unit_pro<0;

** CHECK CASES WHERE AMOUNT SOLD IS GREATER THAN AMOUNT PRODUCED**;

list  unitsold unit_p if  unitsold>unit_p & units!=.;

** CHANGE AMOUNT SOLD TO AMOUNT PRODUCED IF AMOUNT SOLD IS GREATER THAN AMOUNT PRODUCED
  - UNITS FOR SALES SEEM TO BE PROBLEMATIC**;
replace unitsold=unit_p if unitsold>unit_p & unitsold!=.;

** NEED TO DISTINGUISH BETWEEN CROPS SOLD AND CROPS CONSUMED **;
gen crop_consumed=unit_prod-unitsold;

** CONVERT UNITS OF PRODUCTION TO KILOGRAMS OF PRODUCTION **;

** CREATE ADDITIONAL CODES FOR OTHER KINDS OF MEASUREMENT UNIT **;

encode unit_o, generate (unitcode_other);

replace unit=9 if unit==12;  ** assume that a unit is the same as a piece;
replace unit=2 if unitcode_other==1;  ** assume 10 litres is equivalent of 10 kg;

gen Q_not_sold=0;
replace Q_not_sold=crop_consumed if unit==1;
replace Q_not_sold=crop_consumed*10 if unit==2;
replace Q_not_sold=crop_consumed*25 if unit==3;
replace Q_not_sold=crop_consumed*50 if unit==4;
replace Q_not_sold=crop_consumed*80 if unit==5;
replace Q_not_sold=crop_consumed*1000 if unit==6;

replace Q_not_sold=crop_consumed*10 if unit==7;  ** assume a box is 10 kg;

replace Q_not_sold=crop_consumed*25 if unit==8;
replace Q_not_sold=crop_consumed*10 if unit==10;

replace Q_not_sold=crop_consumed*10 if unitcode_o==1;
replace Q_not_sold=crop_consumed*2 if unitcode_o==3;
replace Q_not_sold=crop_consumed*2 if unitcode_o==4;
replace Q_not_sold=crop_consumed*20 if unitcode_o==5;
replace Q_not_sold=crop_consumed*20 if unitcode_o==6;
replace Q_not_sold=crop_consumed*3 if unitcode_o==7;
replace Q_not_sold=crop_consumed*3 if unitcode_o==8;
replace Q_not_sold=crop_consumed*5 if unitcode_o==9;
replace Q_not_sold=crop_consumed*60 if unitcode_o==10;
replace Q_not_sold=crop_consumed*0.75 if unitcode_o==11;
replace Q_not_sold=crop_consumed*90 if unitcode_o==12;
replace Q_not_sold=crop_consumed*10 if unitcode_o==13;
replace Q_not_sold=crop_consumed if unitcode_o==18;
replace Q_not_sold=crop_consumed*10 if unitcode_o==19;
replace Q_not_sold=crop_consumed*25 if unitcode_o==20;

** CHECK CODES 13 - 17 **;
sort unitc;
list cropname unitcode_o unithrv unitsold avgp if unitcode_other>=13 & unitcode_other<=17; 

** CODE 13 - ASSUME THAT A "BASKET" HOLDS 5 KG OF TOMATOES & 10 KG OF POTATOS;  **;
replace Q_not_sold=crop_consumed*5 if unitcode_o==13 &  cropname1==71;
replace Q_not_sold=crop_consumed*10 if unitcode_o==13 &  cropname1==61;

** CODE 14 - ASSUME THAT A "CASE" HOLDS 5 KG OF TOMATOES;  **;
replace Q_not_sold=crop_consumed*5 if unitcode_o==14 &  cropname1==71;

** CODE 15 - ASSUME THAT A "DISH" HOLDS 3 KG;  **;
replace Q_not_sold=crop_consumed*3 if unitcode_o==15;

** CODE 16 - CONVERT DOZENS TO UNITS - ONLY NEEDED FOR MAIZE;  **;
replace Q_not_sold=crop_consumed*$maize*12 if unitcode_o==16 &  cropname1==40;

** CODE 17 - ASSUME THAT "HANDS" = 3 kg of PUMPKINS / CABBAGES / SPINACH;  **;
replace Q_not_sold=crop_consumed*3 if unitcode_o==17;

sort cropname;
log using temp, t replace;
** SOME OF THESE CROPS SIMPLY CAN'T BE MEASURED IN SINGLE PIECES **;
list cropname unit* if unit==9 & (crop==3|crop==21|crop==23|crop==25|cropname1==10|cropname1==15|cropname1==38|
                                    cropname1==41|cropname1==66);
log close;

replace unit=11 if unit==9 & cropname1==68;  ** all spinach looks as though it could be bunches;
replace unit=11 if unit==9 & cropname1==42;  ** 1 obs for Merthi in "pieces" - 72 pieces harvested - change to bunch;
replace crop=2 if unit==9 & crop==1;           ** maize grain PIECES must be ears of maize;
replace unit=11 if unit==9 & cropname1==15;  ** all curry leaves must be bunches;
replace unit=11 if unit==9 & cropname1==10;  ** all carrots look as though it could be bunches;

** DRY BEANS, GREEN BEANS, IMIFINI & MILLET CANNOT BE MEASURED IN PIECES. SET TO MISSING **;
*replace crop_consumed=. if unit==9 & (cropname1==17|cropname1==21|cropname1==29|cropname1==44);

** CODE 9 IS A PIECE/EAR/NUMBER **;
replace Q_not_sold=crop_consumed*$maize if unit==9 & crop==2;  
replace Q_not_sold=crop_consumed*$potato if unit==9 & crop==5; 
replace Q_not_sold=crop_consumed*$orchardfruit if unit==9 & crop==6; 
replace Q_not_sold=crop_consumed*$banana if unit==9 & crop==7; 
replace Q_not_sold=crop_consumed*$pumpkin if unit==9 & crop==10;
replace Q_not_sold=crop_consumed*$greenveg if unit==9 & crop==11;  
replace Q_not_sold=crop_consumed*$madumbe if unit==9 & crop==13;  
replace Q_not_sold=crop_consumed*$tomato if unit==9 & crop==15; 
replace Q_not_sold=crop_consumed*$onion if unit==9 & crop==16; 
replace Q_not_sold=crop_consumed*$sugarcane if unit==9 & crop==17; 
replace Q_not_sold=crop_consumed*$otherveg if unit==9 & crop==18;
replace Q_not_sold=crop_consumed*$avocado if unit==9 & crop==26; 
replace Q_not_sold=crop_consumed*$chili if unit==9 & (crop==27|cropname1==59);
replace Q_not_sold=crop_consumed*$pawpaw if unit==9 & crop==31; 
replace Q_not_sold=crop_consumed*$pineapple if unit==9 & crop==32; 
replace Q_not_sold=crop_consumed*$gemsquash if unit==9 & crop==33; 
replace Q_not_sold=crop_consumed*$butternut if unit==9 & crop==34; 

** DO THE SAME FOR QUANTITIES SOLD - CONVERT TO KG ;

gen Q_sold=0;
replace Q_sold=unitsold if unit==1;
replace Q_sold=unitsold*10 if unit==2;
replace Q_sold=unitsold*25 if unit==3;
replace Q_sold=unitsold*50 if unit==4;
replace Q_sold=unitsold*80 if unit==5;
replace Q_sold=unitsold*1000 if unit==6;

replace Q_sold=unitsold*10 if unit==7;  ** assume a box is 10 kg;

replace Q_sold=unitsold*25 if unit==8;
replace Q_sold=unitsold*10 if unit==10;

replace Q_sold=unitsold*10 if unitcode_o==1;
replace Q_sold=unitsold*2 if unitcode_o==3;
replace Q_sold=unitsold*2 if unitcode_o==4;
replace Q_sold=unitsold*20 if unitcode_o==5;
replace Q_sold=unitsold*20 if unitcode_o==6;
replace Q_sold=unitsold*3 if unitcode_o==7;
replace Q_sold=unitsold*3 if unitcode_o==8;
replace Q_sold=unitsold*5 if unitcode_o==9;
replace Q_sold=unitsold*60 if unitcode_o==10;
replace Q_sold=unitsold*0.75 if unitcode_o==11;
replace Q_sold=unitsold*90 if unitcode_o==12;
replace Q_sold=unitsold*10 if unitcode_o==13;
replace Q_sold=unitsold if unitcode_o==18;
replace Q_sold=unitsold*10 if unitcode_o==19;
replace Q_sold=unitsold*25 if unitcode_o==20;

** CHECK CODES 13 - 17 **;
sort unitc;
list cropname unit* if unitcode_o>=13 & unitcode_o<=17; 

** CODE 13 - ASSUME THAT "BASKETS" HOLD 5 KG OF TOMATOES & 10 KG OF POTATOS;  **;
replace Q_sold=unitsold*5 if unitcode_o==13 &  cropname1==71;
replace Q_sold=unitsold*10 if unitcode_o==13 &  cropname1==61;

** CODE 14 - ASSUME THAT A "CASE" HOLDS 5 KG OF TOMATOES;  **;
replace Q_sold=unitsold*5 if unitcode_o==14 &  cropname1==71;

** CODE 15 - ASSUME THAT A "DISH" HOLDS 3 KG;  **;
replace Q_sold=unitsold*3 if unitcode_o==15;

** CODE 16 - CONVERT DOZENS TO UNITS - ONLY NEEDED FOR MAIZE;  **;
replace Q_sold=unitsold*$maize*12 if unitcode_o==16 &  cropname1==40;

** CODE 17 - ASSUME THAT "HANDS" = 3 kg of PUMPKINS / CABBAGES / SPINACH;  **;
replace Q_sold=unitsold*3 if unitcode_o==17;

sort cropname;
log using temp, t replace;
** SOME OF THESE CROPS SIMPLY CAN'T BE MEASURED IN SINGLE PIECES **;
list cropname unit* if unit==9 & (crop==3|crop==21|crop==23|crop==25|cropname1==10|cropname1==15|cropname1==38|
                                    cropname1==41|cropname1==66);
log close;

** DRY BEANS, GREEN BEANS, IMIFINI & MILLET CANNOT BE MEASURED IN PIECES. SET TO MISSING **;

replace unitsold=. if unit==9 & (cropname1==17|cropname1==21|cropname1==29|cropname1==44);

** CODE 9 IS A PIECE/EAR/NUMBER **;
replace Q_sold=unitsold*$maize if unit==9 & crop==2;  
replace Q_sold=unitsold*$potato if unit==9 & crop==5; 
replace Q_sold=unitsold*$orchardfruit if unit==9 & crop==6; 
replace Q_sold=unitsold*$banana if unit==9 & crop==7; 
replace Q_sold=unitsold*$pumpkin if unit==9 & crop==10;
replace Q_sold=unitsold*$greenveg if unit==9 & crop==11;  
replace Q_sold=unitsold*$madumbe if unit==9 & crop==13;  
replace Q_sold=unitsold*$tomato if unit==9 & crop==15; 
replace Q_sold=unitsold*$onion if unit==9 & crop==16; 
replace Q_sold=unitsold*$sugarcane if unit==9 & crop==17; 
replace Q_sold=unitsold*$otherveg if unit==9 & crop==18;
replace Q_sold=unitsold*$avocado if unit==9 & crop==26; 
replace Q_sold=unitsold*$chili if unit==9 & (crop==27|cropname1==59);
replace Q_sold=unitsold*$pawpaw if unit==9 & crop==31; 
replace Q_sold=unitsold*$pineapple if unit==9 & crop==32; 
replace Q_sold=unitsold*$gemsquash if unit==9 & crop==33; 
replace Q_sold=unitsold*$butternut if unit==9 & crop==34; 


***************************************************************
*                                                             *
*  STEP 2: CALCULATE PRICES PER KG FOR EACH CROP TYPE         *
*                                                             *
***************************************************************;

** CONVERT ALL PRICES TO PRICES PER KG **;
replace avgprice=. if avgprice<0;
gen price_kg=0;
replace price_kg=avgprice if unit==1;
replace price_kg=avgprice/10 if unit==2;
replace price_kg=avgprice/25 if unit==3;
replace price_kg=avgprice/50 if unit==4;
replace price_kg=avgprice/80 if unit==5;
replace price_kg=avgprice/1000 if unit==6;

replace price_kg=avgprice/10 if unit==7;  ** assume a box is 10 kg;

replace price_kg=avgprice/25 if unit==8;
replace price_kg=avgprice/10 if unit==10;

replace price_kg=avgprice/10 if unitcode_o==1;
replace price_kg=avgprice/2 if unitcode_o==3;
replace price_kg=avgprice/2 if unitcode_o==4;
replace price_kg=avgprice/20 if unitcode_o==5;
replace price_kg=avgprice/20 if unitcode_o==6;
replace price_kg=avgprice/3 if unitcode_o==7;
replace price_kg=avgprice/3 if unitcode_o==8;
replace price_kg=avgprice/5 if unitcode_o==9;
replace price_kg=avgprice/60 if unitcode_o==10;
replace price_kg=avgprice/0.75 if unitcode_o==11;
replace price_kg=avgprice/90 if unitcode_o==12;
replace price_kg=avgprice/10 if unitcode_o==13;
replace price_kg=avgprice if unitcode_o==18;
replace price_kg=avgprice/10 if unitcode_o==19;
replace price_kg=avgprice/25 if unitcode_o==20;

** CODE 13 - ASSUME THAT "BASKETS" HOLD 5 KG OF TOMATOES & 10 KG OF POTATOS;  **;
replace price_kg=avgprice/5 if unitcode_o==13 &  cropname1==71;
replace price_kg=avgprice/10 if unitcode_o==13 &  cropname1==61;

** CODE 14 - ASSUME THAT A "CASE" HOLDS 5 KG OF TOMATOES;  **;
replace price_kg=avgprice/5 if unitcode_o==14 &  cropname1==71;

** CODE 15 - ASSUME THAT A "DISH" HOLDS 3 KG;  **;
replace price_kg=avgprice/3 if unitcode_o==15;

** CODE 16 - CONVERT DOZENS TO UNITS - ONLY NEEDED FOR MAIZE;  **;
replace price_kg=avgprice/$maize*12 if unitcode_o==16 &  cropname1==40;

** CODE 17 - ASSUME THAT "HANDS" = 3 kg of PUMPKINS / CABBAGES / SPINACH;  **;
replace price_kg=avgprice/3 if unitcode_o==17;

** CODE 9 IS A PIECE/EAR/NUMBER **;
replace price_kg=avgprice/$maize if unit==9 & crop==2;  
replace price_kg=avgprice/$potato if unit==9 & crop==5; 
replace price_kg=avgprice/$orchardfruit if unit==9 & crop==6; 
replace price_kg=avgprice/$banana if unit==9 & crop==7; 
replace price_kg=avgprice/$pumpkin if unit==9 & crop==10;
replace price_kg=avgprice/$greenveg if unit==9 & crop==11;  
replace price_kg=avgprice/$madumbe if unit==9 & crop==13;  
replace price_kg=avgprice/$tomato if unit==9 & crop==15; 
replace price_kg=avgprice/$onion if unit==9 & crop==16; 
replace price_kg=avgprice/$sugarcane if unit==9 & crop==17; 
replace price_kg=avgprice/$otherveg if unit==9 & crop==18;  
replace price_kg=avgprice/$avocado if unit==9 & crop==26; 
replace price_kg=avgprice/$chili if unit==9 & (crop==27|cropname1==59);
replace price_kg=avgprice/$pawpaw if unit==9 & crop==31; 
replace price_kg=avgprice/$pineapple if unit==9 & crop==32; 
replace price_kg=avgprice/$gemsquash if unit==9 & crop==33; 
replace price_kg=avgprice/$butternut if unit==9 & crop==34; 

** LIST OUTLIERS ON PRICE AND CHECK UNITS **;

replace price=. if price<0.5 & unitsold<=0;
replace price=. if price>25 & unitsold<=0;

replace price=. if price<0.5 & unitsold==.;
replace price=. if price>25 & unitsold==.;

 list  hhid2004 cropname unitname avgprice price if price<.5 & price>0, noobs;
 list  hhid2004 cropname unitname avgprice price if price<. & price>25, noobs;

replace price_kg=. if price_kg<.3;

** SEVERAL CASES WHERE PRICE PER KG IS TOO HIGH - ASSUME THAT THIS IS BECAUSE UNITS OF MEASURE ARE WRONGLY SPECIFIED.**;

egen medprice=median(price_kg) if price>0.5 & price<25, by(crop);

tab crop, sum(avgp);

egen maxmed=max(medprice), by(crop);

replace flag=1 if price_kg==.;

replace price_kg=maxmed if price_kg==.;

gen X_crops=price_kg*(Q_not_sold);
gen SOLD_crops=unitsold*avgprice if units>0 & avgp>0 & units<. & avgp<.;
replace SOLD_crops=price_kg*Q_sold if SOLD_crops==.;
gen Y_crops=X+SOLD;

collapse (sum) Y_crops (max) flag, by(hhid2004) ;

label var Y_crops  "04: Income from crop production (including own consumption" ;

sort hhid2004 ; 
save $OUT\hhyagr, replace ;

** SECTION 8.1.4. TEMP LABOUR **;
use $IN\section8_1_4a;
keep if act>0;
egen medwage=median(wage) if wage>0 & wage~=.;
egen temp=max(medwage);
replace medwage=temp if medwage==.;
gen flagAgL=1 if wage==-4;
replace wage=medwage if wage==-4;
replace meals=0 if meals==-4|meals==-1;
gen labour_cost=numw*daysw*wage+meals if numw>=0 & daysw>=0 & wage>=0;

collapse (sum) labour (max) flag, by(hhid);
sort hhid;
merge hhid using $OUT\hhyagr;
drop _merge;
sort hhid;
save $OUT\hhyagr, replace ;

** SECTION 8.1.4a OTHER AG INPUTS **;
** CANNOT IMPUTE, SO IF MISSING FLAG & SET TO ZERO **;
use $IN\section8_1_4b;
keep if inputs_yn==1;
gen flagAgINPUT=1 if value==-1|value==-4;
replace value=0 if value<0;

collapse (sum) value (max) flag, by(hhid);
sort hhid;
merge hhid using $OUT\hhyagr;
drop _merge;

rename value inputs_other;
lab var inputs "Other agric inputs";
sort hhid;
save $OUT\hhyagr, replace ;

** RENTS & TAXES **;
use $IN\section8_1_4linear;
keep if land>=0|rents>=0;
replace land=0 if land<0;
replace rents=0 if rents<0;
gen taxes=land+rents;

collapse (sum) taxes, by (hhid2004);
sort hhid;

merge hhid using $OUT\hhyagr;
drop _merge;
sort hhid;
save $OUT\hhyagr, replace ;

** section 8.2.2 - no rent received by ANY HH **;

** SECTION 8.3 - LIVESTOCK **;

use $IN\section8_2_3.dta, clear;

keep if anim_yn==1;
replace feed=0 if feed<0;
replace vet=0 if vet<0;

replace sellpric = . if sellpric < 0 ;
egen medsell     = median(sellpric) , by(code) ;
replace sellpric = medsell if sellpric == . & code ~= 8 ;
replace sellpric = 0 if sellpric == . ; 

replace buyprice = . if buyprice < 0 ;
egen medbuy = median(buyprice) , by(code) ;
replace buyprice = medbuy if buyprice == . & anim ~= 8 ;
replace buy      = 0 if code == 7 ;
replace buyprice = 0 if code == 7 ;
replace buyprice = 0 if code == 8 & buy == 0 ;

gen gyanim   = ( sold + slaugh ) * sellpric ;
gen expanim  = ( feedexp + vetexp ) + ( buy * buyp ) ;
gen yanim    = gyanim - expanim  ;

tab code, sum(sellp);
tab code, sum(buyp);

** no major outliers **;

gen ownpro_l = slaugh * sellpric ;
collapse (sum) yanim ownpro_l , by(hhid) ;

label var yanim   "04: Income own lvstk" ;
label var ownpro  "04: Consumption own lvstk" ;

sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;

sort hhid ; save $OUT\hhyagr , replace ;

** Other animal products                                         **;;

use $IN\section8_3;

keep if anim==1;	

gen unitexp = avgprod - avglab - avgsell if avgprod > 0 ;

replace estprice = avgprice if estprice == -1 ;

** Impute missing prices using medians for same product and unit       **;;

sum est if product==1 & unit==13 & est>0, det;
gen flag_OthrP=1 if unit==13 & product==1 & estprice==-4 ;
replace estprice=12 if unit==13 & product==1 & estprice==-4 ;  ** R12 per dozen eggs seems high price;

sum est if product==2 & unit==14 & est>0, det;
replace flag_OthrP=1 if unit==12 & product==2 & estprice<0;
replace estprice=12 if unit==14 & product==2 & estprice==-4 ;  ** R7.50 per litre of milk seems high price;

tab estprice, missing;

replace estprice = . if estprice < 0 ;
replace avgprod  = . if avgprod  < 0 ;

gen othrprod = months * ( avgprod - avglab ) * estprice ;
gen ownpro_o = months * unitexp * estprice ;

collapse (sum) othrprod ownpro_o (max) flag , by(hhid) ;
label var othrprod "04: Income other agric prdtn" ;
label var ownpro_o "04: Consumption own other agric" ;
tab othrprod , missing ;
tab ownpro_o , missing ;
sort hhid ; merge hhid using $OUT\hhyagr ;
tab _merge ; drop _merge ;
sort hhid ; save $OUT\hhyagr , replace ;

** SECTION 8.4. TEMP LABOUR **;
use $IN\section8_4;
keep if tanh_yn==1;
egen medwage=median(wage) if wage>0 & wage~=.;
egen temp=max(medwage);
replace medwage=temp if medwage==.;
gen flagAgTL=1 if wage==-4;
replace wage=medwage if wage==-4;
replace meals=0 if meals==-4|meals==-1;
gen labour2=numw*daysw*wage+meals if numw>=0 & daysw>=0 & wage>=0;

collapse (sum) labour2 (max) flag, by(hhid);
sort hhid;
merge hhid using $OUT\hhyagr;
drop _merge;
sort hhid ; save $OUT\hhyagr , replace ;

** SECTION 8.5. PERMANENT LABOUR **;
use $IN\section8_5;
keep if perm==1;
egen medwage=median(salary) if salary>0 & salary~=.;
egen temp=max(medwage);
replace medwage=temp if medwage==.;
gen flagAgPL=1 if salary==-4;
replace salary=medwage if salary==-4;
replace benef=0 if benef==-4|benef==-1;
gen labour3=numw*month*salary+benef if numw>=0 & month>=0 & salary>=0;

collapse (sum) labour3 (max) flag, by(hhid);
sort hhid;
merge hhid using $OUT\hhyagr;
drop _merge;
sort hhid ; save $OUT\hhyagr , replace ;

** SECTION 8.6. OTHER FARM INCOME - ONLY 9 RECORDS, NO IMPUTATIONS **;
use $IN\section8_6;
collapse value_ca value_ik, by(hhid2004);
sort hhid;
merge hhid using $OUT\hhyagr;
drop _merge;
sort hhid ; save $OUT\hhyagr , replace ;

recode Y_cr .=0;
recode flagAgC .=0;
recode flagAgL .=0;
recode flagAgPL .=0;
recode flagAgTL .=0;
recode flagAgINPUT .=0;
recode flag_OthrP .=0;
recode labour_c .=0;
recode inputs .=0;
recode taxes .=0;
recode yanim .=0;
recode ownpro_l .=0;
recode othrprod .=0;
recode ownpro_o .=0;
recode labour2 .=0;
recode labour3 .=0;
recode value_ca .=0;
recode value_ik .=0;

gen flagAg=1 if flagAgC==1|flagAgL==1|flagAgPL==1|flagAgTL==1|flagAgIN==1|flag_O==1;
recode flagAg .=0;

egen rev = rsum( Y_crop yanim value_ca value_ik) ;
tab rev, missing ;

egen exp = rsum( labour_cost labour2 labour3 taxes inputs ) ;
tab exp, missing ;

gen totagric = rev-exp;
replace totagric=0 if totag<0;
drop rev exp ;
gen hhyagr = totagric/12;

label data         "2004 Household Income from Agriculture" ;
label var hhyagr   "04: Net agric monthly Y" ;
label var totagric "04: Net agric annual Y" ;
label var flagAg  "04: imputation done" ;

sort hhid;
merge hhid using $OUT\temp;
drop _merge;

order hhid2004 ;

sort hhid ; save $OUT\hhyagr , replace ;
