#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYCAS.DO               V : 02              *
*    Date    : 21 SEP 1999                                  *
*    Infile  : CASEMP, HHID                                 *
*    Outfile : YCAS,HHYCAS                                  *
*                                                           *
*    OBJECTIVE: Calculate casual wage income & total        *
*               household income from Casual employment     *
*               (Section 10.3)                              *  
*                                                           *
*************************************************************;;


global IN  = "c:\data\kids3\version1.1";
global OUT = "c:\data\kids3\version1.1\constructed";

use $IN\cover, clear ;    
keep hhid2004;
sort hhid;
save $OUT\temp, replace;

use $IN\section9_3, clear ;         

** Construct 0/1 flag for missing values                                **;;

gen byte flagycas = ( cash < 0 | food_ben < 0 | benefit_ < 0 ) ;

** Set the missing to zero                                              **;;

replace cash = 0 if cash < 0 ;
replace food_ben = 0 if food_ben < 0 ;
replace benefit_ = 0 if benefit_ < 0 ; 
                                   
** Collapse the data to individual level                                **;;
 
collapse (sum) cash food_ben benefit_ (max) flagycas , by( hhid pcode ) ;  
                                                    
label  var  flagycas "(1) if missing value" ;

label data "2004 Individual Casual Wage Income";

desc ;
summ ;

notes drop _dta ;

sort hhid pcode ;
save $OUT\ycas, replace ;     

** Collapse the data to household level                                 **;;
 
collapse (sum) hhcash=cash hhinkd=food_ben hhothr=benefit_ (max) flagycas, 
 by(hhid);  
                           
desc ;
summ ;

** Now merge with entire household list (HHID) and fill in missing      ** 
** values with zeros                                                    **;;

sort hhid;
merge hhid using $OUT\temp ;
assert _merge ~= 1 ; 
           
program drop _all;
                                                                           
** Following program sets valid missing values (after merge) to zero   **;;

program define fillzero ;

 while "`1'"~="" { ;
   replace `1'=0 if `1'==. & _merge==2;
   
   mac shift         ;
   
   }                 ;

end ;


fillzero hhcash hhinkd hhothr flagycas; 

** Construct total casual income                                **;;

gen hhycas = hhcash + hhinkd + hhothr ;

drop _merge ;

label data "2004 Household Casual Wage Income";

label var hhcash   "HH casual wage income : cash";
label var hhinkd   "HH casual wage income : in kind";
label var hhothr   "HH casual wage income : other";
label var hhycas   "HH casual wage income : total" ;
label var flagycas "(1) if HH casual income missing" ;

notes drop _dta ;

order hhid hhcash hhinkd hhothr hhycas flagycas ;

sort hhid; 
save $OUT\hhycas,replace;

desc ;
summ ;

exit ;
