#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYNLAB.DO              V : 01              *
*    Date    : 21 FEB 2005                                  *
*    Infile  : SECTION6, COVER                              *
*    Outfile : YNLAB, HHYNLAB                               *
*                                                           *
*    OBJECTIVE: Calculate monthly income from other         *
*               (non-labour) sources (Section 6)            *
*                                                           *
*************************************************************;

global IN  = "c:\data\kids3\version1.1";
global OUT = "c:\data\kids3\version1.1\constructed";

program drop _all;

use $IN\section6, clear;

drop if source_c==-2;

rename source_c source;

** Exclude packages (source=14) as not current income                    **;;

drop if source == 14 ;

** Impute value as modal response  if missing                            **;;
                               
replace amt_rec1=740 if amt_rec1 < -2 & source ==  1 ;  * OAP;
replace amt_rec1=170 if amt_rec1 < -2 & source ==  15 ; * CSG;
replace amt_rec1=500 if amt_rec1 < -2 & source ==  16 ; * CDG;
replace amt_rec1=530 if amt_rec1 < -2 & source ==  17 ;  * FCG;
replace amt_rec1=740 if amt_rec1 < -2 & source ==  4 ;  * DG;

replace amt_rec2=740 if amt_rec2 < -2 & source ==  1 ;  * OAP;
replace amt_rec2=170 if amt_rec2 < -2 & source ==  15 ; * CSG;
replace amt_rec2=500 if amt_rec2 < -2 & source ==  16 ; * CDG;
replace amt_rec2=530 if amt_rec2 < -2 & source ==  17 ;  * FCG;
replace amt_rec2=740 if amt_rec2 < -2 & source ==  4 ;  * DG;

replace amt_rec3=740 if amt_rec3 < -2 & source ==  1 ;  * OAP;
replace amt_rec3=170 if amt_rec3 < -2 & source ==  15 ; * CSG;
replace amt_rec3=500 if amt_rec3 < -2 & source ==  16 ; * CDG;
replace amt_rec3=530 if amt_rec3 < -2 & source ==  17 ;  * FCG;
replace amt_rec3=740 if amt_rec3 < -2 & source ==  4 ;  * DG;
                   
** Construct 0/1 flag for missing values                                **;;

gen byte flagnlab = ( amt_rec1 < -2 | amt_rec2 < -2 | amt_rec3 < -2 ) ;

replace amt_rec1=0 if amt_rec1<0 ;
replace amt_rec2=0 if amt_rec2<0 ;
replace amt_rec3=0 if amt_rec3<0 ;

* Construct measures of total, state/govt, and private non-labour income **;;

gen state1 = amt_rec1 if source== 1 | source== 4 | source== 6 | source== 8 | source==11 |
                       source==15 | source==16 | source==17 | source==18 | source==19 ;

gen private1 = amt_rec1 if state1 == . ; 

gen state2 = amt_rec2 if source== 1 | source== 4 | source== 6 | source== 8 | source==11 |
                       source==15 | source==16 | source==17 | source==18 | source==19 ;

gen private2 = amt_rec2 if state2 == . ; 

gen state3 = amt_rec3 if source== 1 | source== 4 | source== 6 | source== 8 | source==11 |
                       source==15 | source==16 | source==17 | source==18 | source==19 ;

gen private3 = amt_rec3 if state3 == . ; 

collapse (sum) nonlabY1=amt_rec1 nonlabY2=amt_rec2 nonlabY3=amt_rec3 state1 state2 state3 private1 private2 private3
          (max) flagnlab, by (hhid);  

gen private=private1+private2+private3;
gen state=state1+state2+state3;
drop private1 private2 private3 state1 state2 state3;

gen nonlabY=nonlabY1+nonlabY2+nonlabY3;

drop nonlabY1 nonlabY2 nonlabY3;

lab data "2004 Individual Other (Non-labour) Income";

label var state    "HH other income : state";
label var private  "HH other income : private";
label var flagnlab "(1) if missing other income";  
label var nonlabY  "HH other income : total";

notes drop _dta ;

*sort hhid ;
*save $OUT\ynlab, replace ;     

collapse (sum) nonlabY state private (max) flagnlab, by (hhid);  

lab data "2004 HH Other (Non-labour) Income";

label var state    "HH other income : state";
label var private  "HH other income : private";
label var flagnlab "(1) if missing other income";  
label var nonlabY  "HH other income : total";

notes drop _dta ;

keep hhid state private nonlabY flag ;
order hhid state private nonlabY flag ;

sort hhid ;
save $OUT\hhynlab, replace;

desc ;
summ ;

exit ;
