#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYREM.DO               V : 02              *
*    Date    : 2 FEB 2005                                   *
*    Infile  : SECTION 5.1, cover                           *
*    Outfile : HHYREM                                       *
*                                                           *
*    OBJECTIVE: Calculate the total value of remittances    *
*               received by households  (Section 5.1)       *
*                                                           *
*************************************************************;;

capture log close;
global IN   = "C:\data\kids3\version1.1" ;
global OUT  = "C:\data\kids3\version1.1\constructed";

clear;
use $IN\cover, clear ;    
keep hhid2004;
sort hhid;
save $OUT\temp, replace;

use $IN\section5_1, clear ;                     

** Construct 0/1 flag for missing annual total remittances              **;;

gen byte flagremr = ( r_cash_y < 0 | r_inkin1 < 0 ) ;
  
** List the households with missing annual total remittances            **;;

li if flagremr ;               
                                                           
** For HHs that did not report remittances received, set to missing     **;;

replace r_cash_y = . if r_cash_y < 0 ;
replace r_inkin1 = . if r_inkin1 < 0 ;

replace r_cash_m = . if r_cash_m < 0 ;
replace r_inkin2 = . if r_inkin2 < 0 ; 

**  Calculate total monthly remittances received (sum for each HH)      **
**  and the number of donors (COUNT)                                    **;;

gen int count_r = 1 ;

collapse (sum) r_cash_y r_inkin1 r_cash_m r_inkin2 count_r (max) flagrem
         , by(hhid);

gen totm_cas = r_cash_y / 12 if r_cash_y ~=. ;
gen totm_kin = r_inkin1 / 12 if r_inkin1 ~=. ;
gen hhyrem   = totm_cas + totm_kin ;

desc ;
summ ;

** Now merge with entire household list (HHID) and fill in missing      **
** values with zeros                                                    **;;

sort hhid;
merge hhid using $IN\cover ;
assert _merge ~= 1 ; drop _merge ;

** The following program replaces valid missing values with zeros       ** 
** Use flagremr==0 to ensure valid missing values                       **;; 

replace flagremr=0 if flagremr==. ;

program define fillzero ;

 while "`1'"~="" { ;
   replace `1'=0 if `1'==. & flagremr == 0 ;
   
   mac shift         ;
   
   }                 ;

end ;


fillzero totm_cas totm_kin hhyrem count_r 
         r_cash_y r_cash_m r_inkin1 r_inkin2 ;
      

label data "1904 Household Income from Remittances" ;

label var count_r  "04: Number of donors" ;
label var totm_cas "04: Avg Month Remit income:cash";
label var totm_kin "04: Avg Month Remit income:kind";
label var hhyrem   "04: Avg Month Remit income: all";
label var flagremr "04: (1) if msg annual remit recv";
label var r_cash_y "04: Annual Remit Income:Cash" ;
label var r_inkin1 "04: Annual Remit Income:Kind" ;
label var r_cash_m "04: Past Month Remit Income:Cash" ;
label var r_inkin2 "04: Past Month Remit Income:Kind" ;

notes drop _dta ;

order hhid r_cash_m r_cash_y r_inkin1 r_inkin2 count_r totm_cas totm_kin hhyrem
 flag ;

sort hhid ;
save $OUT\hhyrem, replace ;

desc ;
summ ;

exit; 


