#delimit ;
*************************************************************
*                                                           *
*    Name    : CLCYSEMP.DO              V : 02              *
*    Date    : 20 JAN 2005                                  *
*    Infile  : SECTION9.4                                   *
*    Outfile : HHYSEMP                                      *
*                                                           *
*    OBJECTIVE: Calculate monthly income/profit from        *
*               SELF EMPLOYMENT                             *
*                                                           *
*************************************************************;;

global IN  = "c:\data\kids3\version1.1";
global OUT = "c:\data\kids3\version1.1\constructed";

use $IN\cover, clear ;    
keep hhid2004;
sort hhid;
save $OUT\temp, replace;

use $IN\section9_4, clear ;    

** Construct 0/1 flag for missing values                                **;;
                                                     
gen byte flagsemp = ( grsales_ < 0 | expen_1 < 0 ) ;
         
gen profit = grsales_ - expen_1 if grsales_ >= 0 & expen_1 >= 0 ;  

** There are a number of cases where revenues are less than expenses    **
** yielding negative profits                                            **;

** Part of the underlying problem may be that the one month recall      **
** may be good only for the simplest kinds of businesses leading to     **
** some accounting problems. One must be careful, then in using these   **
** data.                                                                **;

** List households with negative profits                                **;

li hhid business grsales_ expen_1 profit grtime_1 equipval if profit < 0 
   , nodisp noobs;

** List households with very large positive profits                     **;

li hhid business grsales_ expen_1 profit grtime_1 equipval if profit > 5000
   & profit ~= . , nodisp noobs;
                        
sort hhid;
collapse (sum) hhysemp=profit (max) flagsemp, by (hhid);

desc ;
summ ;  

** Now merge with entire household list (HHID) and fill in missing      ** 
** values with zeros                                                    **;;

sort hhid;
merge hhid using $OUT\temp;
assert _merge ~= 1 ; 

replace hhysemp  = 0 if _merge == 2 ;
replace flagsemp = 0 if _merge == 2 ;

drop _merge ;

label data "2004 Household Self Employment Income" ;
label var hhysemp  "04: HH self-employ income|profit" ;
label var flagsemp "04: (1) if HH self-employ Y msg" ;

notes drop _dta ;

notes : Caution: Some reported figures appear to be outliers, possibly due
        to one-month recall period ;

sort hhid ;
save $OUT\hhysemp,replace;

desc ;
summ ;



