#delimit ;
*************************************************************
*                                                           *
*    Name    : OCCNFEXP.DO                V : 01            *
*    Date    : 12 NOV 2004                                  *
*    Infile  : SECTION4.2, SECTION 1.5                      *
*    Outfile : OCCNFEXP.DTA                                 *
*                                                           *
*    OBJECTIVE: Calculate total household monthly           *
*               expenditure for occasional                  *
*               non-food commodities (Section 4.2)          *
*                                                           *
*               Cluster & item medians used to impute       *
*               missing values unless otherwise noted       *
*                                                           *
*************************************************************;;

clear;
capture log close;
capture program drop fillmedn;

global IN  = "c:\data\kids3\version1.1";
global OUT = "c:\data\kids3\version1.1\constructed";

use $IN\roster2004.dta, clear ;
rename race q1;
egen race=max(q1), by(hhid2004);
egen race2=min(q1), by(hhid2004);  ** there are some hh with Coloured & White members -
                                we want to assign hhs as African or Indian wherever possible;

replace race=race2 if race==2|race==4;

replace race=1 if hhid2004==205008040;  ** hh where all members are african except one person with missing code;

collapse race, by(hhid2004);
sort hhid2004;
save $OUT\race_hh, replace;

use $IN\section4_2.dta, clear ;
rename cluster clustnum;

** Note: 24 Households report nothing (i.e. zero expenditures) here     **;;
sort hhid2004;
merge hhid2004 using $OUT\race_hh ;
tab _merge;
drop _merge ;

** Construct 0/1 flag for missing values                                **;;

gen byte flagocc = ( onfs_a < 0 ) ;

** Calculate cluster & race medians of nonzero purchases                **;;

egen medpval = median(onfs_a) if (onfs_a>0 & onfs_a~=.), 
               by(onfs_c clust) ;
                
egen medval  = min(medpval),  by(onfs_c clust) ; 

** List the households and items with missing values and the            **
** corresponding median values for imputations                          **;;

li hhid2004 onfs_c medval if flagocc , noobs nolabel ; 

**  	THERE ARE 18 MISSING VALUES WHERE MEDIAN FOR CLUSTER IS ALSO MISSING - USE RACE MEDIAN **;

egen medval_r = median(onfs_a) if (onfs_a>0 & onfs_a~=.), 
               by(onfs_c race) ;
                
egen medrval  = min(medpval),  by(onfs_c race) ; 

li hhid2004 onfs_c medrval if medval==. & flagocc , noobs nolabel ; 

replace medval=medrval if medval==. & flag;

drop medval_r medrval;

** Replace missing observations with cluster & race medians             **;;

** Median for cluster 195 with missing rnfs_c=19 is also missing        **
** treat as zero  (short term insurance)                                **;;

** The following program constructs temporary variables to calculate    **
** household level expenditures, replacing missing values with medians  **;;

program define fillmedn ;

 while "`1'"~="" { ;

   gen com`1'     = onfs_a if onfs_c==`1' & flagocc==0 ;
   replace com`1' = medval if onfs_c==`1' & flagocc==1 ;
 
   mac shift         ;
   
   }                 ;

end ;


fillmedn 1 2 3 4  7 8 9 10 11 12 13 14 15 16 17 18 19 21 22 23 24;

                                                    
** Calculate the occasional nonfood expenditures at the household level ** 
** using the temporary variables constructed above                      **
** Note: The "egen & summ" command turns missing values into zeros      **;;

egen yxkitchen    = sum(com1) , by (hhid2004) ;
egen yxhome    = sum(com2) , by (hhid2004) ;
egen yxbedding    = sum(com3) , by (hhid2004) ;
egen yxfurniture   = sum(com4) , by (hhid2004) ;
egen yxadult_clothes   = sum(com22), by (hhid2004) ;
egen yxkid_clothes   = sum(com21), by (hhid2004) ;                  
egen yxfabric   = sum(com7) , by (hhid2004) ;
egen yxdoctors    = sum(com8) , by (hhid2004) ;
egen yxhospital   = sum(com9) , by (hhid2004) ;
egen yxmedical_supplies  = sum(com10), by (hhid2004) ;
egen yxtradhealers   = sum(com11), by (hhid2004) ;
egen yxholidays   = sum(com12), by (hhid2004) ;
egen yxluxuries    = sum(com13), by (hhid2004) ;    
egen yxceremonies  = sum(com23), by (hhid2004) ;    
egen yxschool_fees  = sum(com14), by (hhid2004) ;    
egen yxuniversity  = sum(com15), by (hhid2004) ;    
egen yxed_books   = sum(com16), by (hhid2004) ;  
egen yxedothr = sum(com17), by (hhid2004) ;    
egen yxmed_aid  = sum(com18), by (hhid2004) ;    
egen yxins_s  = sum(com19), by (hhid2004) ;   
egen yxins_l  = sum(com24), by (hhid2004) ;   

** Calculate total yearly occasional non-food expenditure for household **;;
  
gen yxtot = yxkit   + yxhom + yxbed + yxfurn + yxad + yxkid_cl + yxfabric + 
            yxdoc   + yxhosp + yxmedical_s + yxmed_aid+ yxtrad + yxholi + yxlux + yxcerem +
            yxschool + yxuniv + yxed_book + yxedothr + yxins_l + yxmed_ + yxins_s ;       

** Label Variables                                                      **;;

label data "1998 Occasional Non-Food Expenditures";

label var yxkit    "04: Year exp: Kitchen equip" ;
label var yxhom    "04: Year exp: Home repair" ;
label var yxbed    "04: Year exp: Bedding/Towels" ;
label var yxfurn   "04: Year exp: Furniture/Appl" ;
label var yxad   "04: Year exp: ADULT clothes" ;
label var yxkid_cl   "04: Year exp: CHILD clothes" ;
label var yxfabric   "04: Year exp: Material/fabric" ;
label var yxdoc    "04: Year exp: Dentist/Doc/Nurse" ;
label var yxhosp   "04: Year exp: Hospital Fees" ;
label var yxmedical_s  "04: Year exp: Medical Supplies" ;
label var yxtrad   "04: Year exp: Traditional Healer" ;
label var yxholi   "04: Year exp: Holidays" ;
label var yxlux    "04: Year exp: Luxury Goods" ;
label var yxcerem  "04: Year exp: Ceremonies" ;
label var yxschool  "04: Year exp: School fees" ;
label var yxuniv  "04: Year exp: University/college fees" ;
label var yxed_book   "04: Year exp: School book/unifrm" ;
label var yxedothr "04: Year exp: Other school" ;
label var yxmed_aid  "04: Year exp: Medical aid" ;
label var yxins_l  "04: Year exp: Insurance -life & funeral" ;
label var yxins_s  "04: Year exp: Insurance -short-term" ;   
label var yxtot    "04: Year exp: Total Occ Non Food" ;
label var flagocc  "04: (1) if any exp item imputed" ; 
     
** Construct household level file, sort to retain non-zero flags        **;;

drop onfs_c onfs_a medval medpval  com* race clustnum ;
gsort + hhid2004 - flag ;
quietly by hhid2004: keep if _n==1 ;

notes drop _dta ;

order hhid2004 yxkit yxhom yxbed yxfurn yxad yxkid yxfabric yxdoc yxhosp yxmedical_s yxmed_aid
 yxtrad yxholi yxlux yxcerem yxschool yxuniv yxed_book yxedothr yxins_l yxins_s
 yxtot flag ;

sort hhid2004 ;
save $OUT\occnfexp, replace ;         
